@@ -185,7 +185,7 @@ function group_get_public_active_projects_asc($max_query_limit = -1) {
 }
 
 
-class Group extends Error {
+class Group extends FFError {
 	/**
 	 * Associative array of data from db.
 	 *
@@ -236,7 +236,7 @@ class Group extends Error {
 	 * @param	int|bool	$res	Database result from select query OR associative array of all columns.
 	 */
 	function __construct($id = false, $res = false) {
-		$this->Error();
+		parent::__construct();
 		if (!$id) {
 			//setting up an empty object
 			//probably going to call create()
@@ -1576,6 +1576,35 @@ class Group extends Error {
 		}
 		return $this->data_array['homepage'];
 	}
+	/**
+	 * setHomepage - the hostname of the scm box where this project is located.
+	 *
+	 * @param	string	$homepage	The name of the new HOMEPAGE
+	 * @return	bool
+	 */
+	function setHomepage($homepage) {
+
+		if ($homepage == $this->data_array['homepage']) {
+			return true;
+		}
+		if ($homepage) {
+			db_begin();
+			$res = db_query_params('UPDATE groups SET homepage=$1 WHERE group_id=$2', array($homepage, $this->getID()));
+			if ($res) {
+				$this->addHistory('homepage', $this->data_array['homepage']);
+				$this->data_array['homepage'] = $homepage;
+				db_commit();
+				return true;
+			} else {
+				db_rollback();
+				$this->setError(_("Could not insert homepage to database"));
+				return false;
+			}
+		} else {
+			$this->setError(_("Homepage cannot be empty"));
+			return false;
+		}
+	}
 
 	/**
 	 * getTags - Tags of this project.
@@ -2286,6 +2315,10 @@ class Group extends Error {
 	 * @access public
 	 */
 	function addHistory($field_name, $old_value) {
+            if ($old_value == NULL) {
+                    $old_value = '';
+            }
+
 		return db_query_params ('INSERT INTO group_history(group_id,field_name,old_value,mod_by,adddate)
 			VALUES ($1,$2,$3,$4,$5)',
 					array($this->getID(),
