@@ -48,11 +48,8 @@ class SVNPlugin extends SCMPlugin {
 _("This plugin contains the Subversion subsystem of FusionForge. It allows
 each FusionForge project to have its own Subversion repository, and gives
 some control over it to the project's administrator.");
-		$this->svn_root_fs = '/scmrepos/svn';
-		if (!file_exists($this->svn_root_fs.'/.')) {
-			$this->svn_root_fs = forge_get_config('repos_path',
-			    $this->name);
-		}
+		$this->svn_root_fs = forge_get_config('repos_path',
+											  $this->name);
 		$this->svn_root_dav = '/svn';
 		$this->_addHook('scm_browser_page');
 		$this->_addHook('scm_update_repolist');
@@ -293,6 +290,10 @@ some control over it to the project's administrator.");
 				return false;
 			}
 			system ("sed -i '/enable-rep-sharing = false/s/^. //' $repo/db/fsfs.conf") ;
+			// dav/ directory is required by old svn clients (eg. svn 1.6.17 on ubuntu 12.04)
+			if (!is_dir ("$repo/dav")) {
+				mkdir("$repo/dav");
+			}
 			system ("svn mkdir -m'Init' file:///$repo/trunk file:///$repo/tags file:///$repo/branches >/dev/null") ;
 			system ("find $repo -type d -print0 | xargs -r -0 chmod g+s") ;
 			// Allow read/write users to modify the SVN repository
@@ -585,7 +586,7 @@ some control over it to the project's administrator.");
 			curl_setopt($ch, CURLOPT_WRITEFUNCTION, 'curl2xml');
 			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
 			curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
-			curl_setopt($ch, CURLOPT_COOKIE, $_SERVER['HTTP_COOKIE']);  // for session validation
+			curl_setopt($ch, CURLOPT_COOKIE, @$_SERVER['HTTP_COOKIE']);  // for session validation
 			curl_setopt($ch, CURLOPT_USERAGENT, $_SERVER['HTTP_USER_AGENT']);  // for session validation
 			curl_setopt($ch, CURLOPT_HTTPHEADER,
 						array('X-Forwarded-For: '.$_SERVER['REMOTE_ADDR']));  // for session validation
@@ -597,10 +598,9 @@ some control over it to the project's administrator.");
 
 			// final checks
 			if (!xml_parse($xml_parser, '', true))
-				exit_error('Unable to parse XML with error '
+				$this->setError('Unable to parse XML with error '
 						   . xml_error_string(xml_get_error_code($xml_parser))
-						   . ' on line ' . xml_get_current_line_number($xml_parser),
-					'activity');
+						   . ' on line ' . xml_get_current_line_number($xml_parser));
 			xml_parser_free($xml_parser);
 
 			if ($adds > 0 || $updates > 0 || $commits > 0 || $deletes > 0) {
@@ -685,10 +685,9 @@ some control over it to the project's administrator.");
 
 			// final checks
 			if (!xml_parse($xml_parser, '', true))
-				exit_error('Unable to parse XML with error '
+				$this->setError('Unable to parse XML with error '
 						   . xml_error_string(xml_get_error_code($xml_parser))
-						   . ' on line ' . xml_get_current_line_number($xml_parser),
-					'activity');
+						   . ' on line ' . xml_get_current_line_number($xml_parser));
 			xml_parser_free($xml_parser);
 
 			if ($adds > 0 || $updates > 0 || $commits > 0 || $deletes > 0) {
